@@ -23,6 +23,7 @@ from .datamodels.datamodels.api import (
     InferenceDeploymentIn,
     InferenceDeploymentStatus,
     InferenceDeploymentAutoscalingConfig,
+    LLMLoraConfig,
     ProviderEnum,
 )
 from .utils import CategorizedMutuallyExclusiveOption, PatchedCommand
@@ -225,6 +226,28 @@ def verify_cloud_config_options(kwargs: Dict[str, Any]):
         )
 
 
+def verify_lora_options(kwargs: Dict[str, Any]):
+    args = [kwargs["lora_adapter_repo"], kwargs["lora_adapter_name"]]
+    if any(args):
+        if not all(args):
+            click.echo(
+                click.style(
+                    "Error: lora_adapter_name and lora_adapter_repo must be provided together",
+                    fg="red",
+                ),
+                err=True,
+            )
+            exit()
+    else:
+        return None
+
+    return LLMLoraConfig(
+        name=kwargs["lora_adapter_name"],
+        hf_repo=kwargs["lora_adapter_repo"],
+        hf_token=kwargs.get("lora_adapter_hf_token"),
+    )
+
+
 @click.group(name="infer", chain=True)
 def infer():
     """
@@ -563,6 +586,28 @@ def create_inf_dep(
     show_default=True,
     category="Controller node configuration options",
 )
+# ******************************* OPTIMAL WORKER CONFIGURATION OPTIONS *******************************
+@click.option(
+    "--lora_adapter_repo",
+    type=click.STRING,
+    required=False,
+    help="Specify the hf repo name of the lora adapter to use",
+    show_default=True,
+)
+@click.option(
+    "--lora_adapter_name",
+    type=click.STRING,
+    required=False,
+    help="Specify the name for the lora adapter",
+    show_default=True,
+)
+@click.option(
+    "--lora_adapter_hf_token",
+    type=click.STRING,
+    required=False,
+    help="Specify the HF Hub token for the lora adapter repo",
+    show_default=True,
+)
 @click.option("-f", "--force", is_flag=True)
 @click.option("-q", "--quiet", is_flag=True)
 def create_impl(**inference_kwargs: Any):
@@ -573,6 +618,9 @@ def create_impl(**inference_kwargs: Any):
     # Verify controller_config
     controller_config = verify_cloud_config_options(inference_kwargs)
 
+    # Verify lora config
+    lora_config = verify_lora_options(inference_kwargs)
+
     # Get existing deployments
     deployments: List[Dict[str, Any]] = get_deployments(should_exist=False)
 
@@ -628,6 +676,7 @@ def create_impl(**inference_kwargs: Any):
         "name": inference_kwargs["name"],
         "model": inference_kwargs["model"],
         "base_model": inference_kwargs["base_model"],
+        "llm_loras": lora_config,
         "inf_type": inference_kwargs["inf_type"],
         "engine": inference_kwargs["engine"],
         "hf_token": inference_kwargs["hf_token"],
@@ -745,7 +794,7 @@ def start_impl(inf_id: str, force: bool, quiet: bool):
         resp_data = resp.json()
         click.echo(
             click.style(
-                f"\nScale up requset for deployment: {inf_id} was sent successfully",
+                f"\nScale up request for deployment: {inf_id} was sent successfully",
                 fg="green",
             )
         )
@@ -780,6 +829,45 @@ def start_impl(inf_id: str, force: bool, quiet: bool):
         )
 
 
+@infer.command("stop")
+@click.argument("inf_id", type=click.STRING, required=True)
+def stop_impl(inf_id: str):
+    """
+    Allows user to make the InferenceDeployment go to INACTIVE state
+    """
+
+    dep = get_deployment(inf_id)
+    if dep["status"] != InferenceDeploymentStatus.ACTIVE:
+        click.echo(
+            click.style(f"Deployment with inf_id {inf_id} is not active", fg="red"),
+            err=True,
+        )
+        exit()
+
+    console = Console()
+    with console.status(f"[bold green]Scaling deployment with inf_id {inf_id}...") as _:
+        resp = send_request("POST", f"/sg_inf/{inf_id}/scale/zero")
+
+    if resp.status_code == 200:
+        resp_data = resp.json()
+        click.echo(
+            click.style(
+                f"Stop/Scale to Zero request for deployment: {inf_id} was sent successfully",
+                fg="green",
+            )
+        )
+    else:
+        resp_data = resp.content.decode("utf-8")
+        click.echo(
+            click.style(
+                f"\nSomething went wrong: {resp_data}. Please try scaling deployment later",
+                fg="red",
+            ),
+            err=True,
+        )
+        exit()
+
+
 @infer.command("delete")
 @click.argument("inf_id", type=click.STRING, required=True)
 @click.option("-q", "--quiet", is_flag=True)
